@@ -133,9 +133,6 @@ gboolean       ev_view_next_page	  (EvView         *view);
 gboolean       ev_view_previous_page	  (EvView         *view);
 gchar*         ev_view_page_label_from_dest (EvView *view, EvLinkDest *dest);
 
-void           ev_view_update_view_size   (EvView            *view,
-					   GtkScrolledWindow *scrolled_window);
-
 void	       ev_view_autoscroll_start   (EvView *view);
 void           ev_view_autoscroll_stop    (EvView *view);
 
